--
-- Newb Dev Box
-- Version: NDB 2.5.100007
-- Author: Walkerbo
-- Email: walkerbo.saurfang@gmail.com
-- Date: Wednesday 22 March 2023
--

-- I have tried to name variables, functions, frames, and buttons to be descriptive

-- ===================================================================================================
-- ===================================================================================================
-- ===========================         Metrics, Lists & Variables          ===========================
-- ===================================================================================================
-- ===================================================================================================

local addonName = "Newb Dev Box"
local versionNumber = "NDB 2.5.100007"

local ListOfDevAddons = {
    "BugSack",
    "REHack",
    "ViragDevTool",
    "WowLua",
    "APIInterface",
    "HandleIt",
    "WhatsOnTheMap",
    "Cube",
    "AddonUsage"
}

local bugsackFunctions = _G["BugSack"] -- set a local reference to bugsack

local SortedNewbDevBoxButtonTable = {}

local stringNewbDevBox, -- default strings
    stringKeyBindings,
    stringToggleFrame,
    stringReload,
    stringLogout,
    stringFStack,
    stringETrace,
    stringChatLog,
    stringCombatLog,
    stringClearChat,
    stringChatSpacer,
    stringETraceStart,
    stringETraceStop,
    stringExit,
    stringBugSack,
    stringBugSackClear,
    stringWoWLuaButton,
    stringREHackButton,
    stringViragDevTool,
    stringAPIInterface,
    stringHandleIt,
    stringVersion,
    stringVersionPrint,
    stringFrameScale,
    stringFrameOpacity,
    stringWhatsOnTheMapButton,
    stringCubeCodeButton,
    stringCubeBrowserButton,
    stringAddonUsageButton =
    "Newb Dev Box",
    "Keybindings",
    "Toggle Frame",
    "Reload",
    "Logout",
    "FStack",
    "ETrace",
    "Chat Log",
    "Combat Log",
    "Clear Chat",
    "Chat Spacer",
    "ETrace Start",
    "ETrace Stop",
    "Exit",
    "Bug Sack",
    "Clear Bug Sack",
    "WoW Lua",
    "REHack",
    "Virag Dev Tool",
    "API Interface",
    "Handle It",
    "Version",
    "Current Version -:",
    "% Button Box Scale",
    "% Button Box Opacity",
    "Whats On The Map",
    "Cube Code",
    "Cube Browser",
    "Addon Usage"

local TextDimensionList = {
    addonColour = "|cff00ff00", -- rgb(0, 255, 0)
    disabledTextColour = "|cff918f8e", -- rgb(145, 143, 142)
    colourBackdrop = {0, 0, 0, 1}, -- rgb(0, 0, 0)
    colourBorder = {0, 1, 0, 1}, -- rgb(0, 255, 0)
    checkBoxTextColour = "|cffffd100", -- rgb(255, 209, 0)
    checkBoxFont = FocusFontSmall,
    keybindButtonFont = ErrorFont,
    buttonFont = Game13FontShadow, -- debug -- NumberFontNormal -- NumberFontNormalLarge
    buttonTemplate = "GameMenuButtonTemplate", -- debug -- BigRedThreeSliceButtonTemplate
    secureButtonTemplate = "SecureActionButtonTemplate, GameMenuButtonTemplate"
}

-- ===========================         font objects          ===========================
local NewbDevBoxTitle = CreateFont("NewbDevBoxTitle")
NewbDevBoxTitle:SetFont("Interface\\AddOns\\NewbDevBox\\Files\\OCRAStd.otf", 32, "")
local NewbDevBoxButton = CreateFont("NewbDevBoxButton")
NewbDevBoxButton:SetFont("Interface\\AddOns\\NewbDevBox\\Files\\OCRAStd.otf", 16, "")

-- ===========================         all the strings          ===========================
local TextStringList = {
    addonLoaded = TextDimensionList.addonColour .. " *** " .. addonName .. " - " .. versionNumber .. " Loaded *** \n",
    interfaceTitle = TextDimensionList.addonColour .. stringNewbDevBox,
    btnAPIInterfaceButton = stringAPIInterface,
    btnBugSackButton = stringBugSack,
    btnBugSackClearButton = stringBugSackClear,
    btnChatLog = stringChatLog,
    btnChatSpacer = stringChatSpacer,
    btnClearChat = stringClearChat,
    btnCombatLog = stringCombatLog,
    btnETrace = stringETrace,
    btnEtraceStart = stringETraceStart,
    btnEtraceStop = stringETraceStop,
    btnExit = stringExit,
    btnFStack = stringFStack,
    btnCubeButton = stringCubeCodeButton,
    btnCubeBrowserButton = stringCubeBrowserButton,
    btnHandleIt = stringHandleIt,
    btnLogout = stringLogout,
    btnNewbDevBox = stringNewbDevBox,
    btnREHackButton = stringREHackButton,
    btnReload = stringReload,
    btnVersionButton = stringVersion,
    btnViragDevToolButton = stringViragDevTool,
    btnWhatsOnTheMapButton = stringWhatsOnTheMapButton,
    btnWoWLuaButton = stringWoWLuaButton,
    btnAddonUsageButton = stringAddonUsageButton,
    cbAddonUsageButton = " " .. stringAddonUsageButton,
    cbAPIInterfaceButton = " " .. stringAPIInterface,
    cbBugSackButton = " " .. stringBugSack,
    cbBugSackClearButton = " " .. stringBugSackClear,
    cbChatLog = " " .. stringChatLog,
    cbChatSpacer = " " .. stringChatSpacer,
    cbClearChat = " " .. stringClearChat,
    cbCombatLog = " " .. stringCombatLog,
    cbETrace = " " .. stringETrace,
    cbEtraceStart = " " .. stringETraceStart,
    cbEtraceStop = " " .. stringETraceStop,
    cbExit = " " .. stringExit,
    cbFStack = " " .. stringFStack,
    cbCubeCodeButton = " " .. stringCubeCodeButton,
    cbCubeBrowserButton = " " .. stringCubeBrowserButton,
    cbHandleIt = " " .. stringHandleIt,
    cbLogout = " " .. stringLogout,
    cbREHackButton = " " .. stringREHackButton,
    cbVersionButton = " " .. stringVersion,
    cbViragDevToolButton = " " .. stringViragDevTool,
    cbWhatsOnTheMapButton = " " .. stringWhatsOnTheMapButton,
    cbWoWLuaButton = " " .. stringWoWLuaButton,
    printChatSpacer = TextDimensionList.addonColour .. "********************************************************",
    printVersion = TextDimensionList.addonColour .. stringVersionPrint,
    textBoxScale = stringFrameScale,
    textBoxOpacity = stringFrameOpacity,
    keyBinding = stringKeyBindings,
    toggleFrame = stringToggleFrame
}

local NumberList = {
    actionButtonHeight = 30,
    actionButtonSideFrameGap = 14,
    actionButtonSideGap = 6,
    actionButtonTopGap = -32,
    actionButtonWidth = 135,
    buttonFrameDefaultHeight = 83,
    buttonFrameHeightExpander = 34,
    buttonFrameTitleButtonWidth = 150,
    buttonFrameWidth = 440.5,
    checkBoxElementXGap = 165,
    checkBoxElementYGap = -55,
    checkBoxMainSideGap = 35,
    checkBoxMainTopGap = -70,
    checkBoxSize = 27,
    edgeSize = 20,
    insetSize = 5,
    keybindingsButtonHeight = 34,
    keybindingsButtonWidth = 180,
    scaleTextBoxHeight = 25,
    scaleTextBoxWidth = 40,
    scaleTextBoxXGap = 415,
    textBoxYGap = -10,
    titleFrameGap = -14,
    titleFrameHeight = 40,
    titleFrameWidth = 600
}

-- ===========================         global keybinding Names          ===========================
BINDING_HEADER_NEWBDEVBOXKEYBINDINGTITLE = "- Newb Dev Box -"
BINDING_NAME_NEWBDEVBOXTOGGLENEWBDEVBOXINTERFACEFRAME = "Toggle NDB Interface Frame"
BINDING_NAME_NEWBDEVBOXTOGGLENEWBDEVBOXBUTTONFRAME = "Toggle NDB Button Frame"

-- ===================================================================================================
-- ===================================================================================================
-- ===========================         functions          ===========================
-- ===================================================================================================
-- ===================================================================================================

local function initialiseLists() -- build lists if they do not already exist
    if not NewbDevBoxDisplayButtonsList then
        NewbDevBoxDisplayButtonsList = {
            [1] = {LogoutButton = true},
            [2] = {ExitButton = true},
            [3] = {FStackButton = true},
            [4] = {ClearChatButton = true},
            [5] = {ChatSpacerButton = true},
            [6] = {ETraceButton = true},
            [7] = {ETraceStartButton = true},
            [8] = {ETraceStopButton = true},
            [9] = {ChatLogButton = true},
            [10] = {CombatLogButton = true},
            [11] = {VersionButton = true},
            [12] = {BugSackButton = false},
            [13] = {BugSackClearButton = false},
            [14] = {WoWLuaButton = false},
            [15] = {REHackButton = false},
            [16] = {ViragDevToolButton = false},
            [17] = {APIInterfaceButton = false},
            [18] = {HandleItButton = false},
            [19] = {WhatsOnTheMapButton = false},
            [20] = {CubeCodeButton = false},
            [21] = {CubeBrowserButton = false},
            [22] = {AddonUsageButton = false}
        }
    end
    if not NewbDevBoxOptionsTable then
        NewbDevBoxOptionsTable = {
            ButtonFrameScale = 1,
            ButtonFrameOpacity = 1,
            ButtonIsVisable = true
        }
    end
end

local function setUpNewbDevBoxSortedTable()
    for k in pairs(NewbDevBoxDisplayButtonsList) do -- insert the key of our button table
        table.insert(SortedNewbDevBoxButtonTable, k)
    end
    table.sort(SortedNewbDevBoxButtonTable) -- sort the key values table
end

local function setCheckBoxesAndButtonFrameMetrics() -- set up the checkboxes and the frame and buttons scale
    for index = 1, #SortedNewbDevBoxButtonTable do -- loop through the sorting table
        tableIndex = SortedNewbDevBoxButtonTable[index] -- get the current index
        tableAtIndex = NewbDevBoxDisplayButtonsList[tableIndex] -- get the table held in the button table index
        for k, v in pairs(tableAtIndex) do -- loop through the table at index
            buttonName = _G["NewbDevBoxInterfaceFramecb" .. k] -- this is our current checkbox name
            if v then -- if true
                buttonName:SetChecked(true) -- check checkbox
            end
        end
    end
    NewbDevBoxButtonFrame:SetScale(NewbDevBoxOptionsTable.ButtonFrameScale) -- set the frame scale
    NewbDevBoxInterfaceFrame.ScaleTextBox:SetNumber(NewbDevBoxOptionsTable.ButtonFrameScale * 100) -- get the scale size and display it
    NewbDevBoxInterfaceFrame.ScaleTextBox:SetCursorPosition(0)
    NewbDevBoxButtonFrame:SetAlpha(NewbDevBoxOptionsTable.ButtonFrameOpacity) -- set the frame opacity
    NewbDevBoxInterfaceFrame.OpacityTextBox:SetNumber(NewbDevBoxOptionsTable.ButtonFrameOpacity * 100) -- get the opacity value and display it
    NewbDevBoxInterfaceFrame.OpacityTextBox:SetCursorPosition(0)
    if NewbDevBoxOptionsTable.ButtonIsVisable then -- if the button was visable last time
        NewbDevBoxButtonFrame:Show()
    else
        NewbDevBoxButtonFrame:Hide()
    end
end

local function checkOtherAddonsEnabled()
    for k, v in pairs(ListOfDevAddons) do
        local name, title, _, enabled = GetAddOnInfo(v)
        if name == "BugSack" then
            if enabled then -- if addon is loaded enable checkboxes and remove grey text
                NewbDevBoxInterfaceFramecbBugSackButton.text:SetText(TextStringList.cbBugSackButton)
                NewbDevBoxInterfaceFramecbBugSackButton:Enable()
                NewbDevBoxInterfaceFramecbBugSackClearButton.text:SetText(TextStringList.cbBugSackClearButton)
                NewbDevBoxInterfaceFramecbBugSackClearButton:Enable()
            else -- ensure button variables are set to false
                NewbDevBoxDisplayButtonsList[12].BugSackButton = false
                NewbDevBoxDisplayButtonsList[13].BugSackClearButton = false
            end
        elseif name == "WowLua" then
            if enabled then
                NewbDevBoxInterfaceFramecbWoWLuaButton.text:SetText(TextStringList.cbWoWLuaButton)
                NewbDevBoxInterfaceFramecbWoWLuaButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[14].WoWLuaButton = false
            end
        elseif name == "REHack" then
            if enabled then
                NewbDevBoxInterfaceFramecbREHackButton.text:SetText(TextStringList.cbREHackButton)
                NewbDevBoxInterfaceFramecbREHackButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[15].REHackButton = false
            end
        elseif name == "ViragDevTool" then
            if enabled then
                NewbDevBoxInterfaceFramecbViragDevToolButton.text:SetText(TextStringList.cbViragDevToolButton)
                NewbDevBoxInterfaceFramecbViragDevToolButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[16].ViragDevToolButton = false
            end
        elseif name == "APIInterface" then
            if enabled then
                NewbDevBoxInterfaceFramecbAPIInterfaceButton.text:SetText(TextStringList.cbAPIInterfaceButton)
                NewbDevBoxInterfaceFramecbAPIInterfaceButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[17].APIInterfaceButton = false
            end
        elseif name == "HandleIt" then
            if enabled then
                NewbDevBoxInterfaceFramecbHandleItButton.text:SetText(TextStringList.cbHandleIt)
                NewbDevBoxInterfaceFramecbHandleItButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[18].HandleItButton = false
            end
        elseif name == "WhatsOnTheMap" then
            if enabled then
                NewbDevBoxInterfaceFramecbWhatsOnTheMapButton.text:SetText(TextStringList.cbWhatsOnTheMapButton)
                NewbDevBoxInterfaceFramecbWhatsOnTheMapButton:Enable()
                WhatsOnTheMapDB.empty = true
                C_Timer.After(
                    .3,
                    function()
                        WhatsOnTheMapFrame:Hide()
                    end
                )
            else
                NewbDevBoxDisplayButtonsList[19].WhatsOnTheMapButton = false
            end
        elseif name == "Cube" then
            if enabled then
                NewbDevBoxInterfaceFramecbCubeCodeButton.text:SetText(TextStringList.cbCubeCodeButton)
                NewbDevBoxInterfaceFramecbCubeCodeButton:Enable()
                NewbDevBoxInterfaceFramecbCubeBrowserButton.text:SetText(TextStringList.cbCubeBrowserButton)
                NewbDevBoxInterfaceFramecbCubeBrowserButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[20].CubeCodeButton = false
                NewbDevBoxDisplayButtonsList[21].CubeBrowserButton = false
            end
        elseif name == "AddonUsage" then
            if enabled then
                NewbDevBoxInterfaceFramecbAddonUsageButton.text:SetText(TextStringList.cbAddonUsageButton)
                NewbDevBoxInterfaceFramecbAddonUsageButton:Enable()
            else
                NewbDevBoxDisplayButtonsList[22].AddonUsageButton = false
            end
        end
    end
end

local function buttonFrameButtonLayout()
    local lastRelative, lastOnTop = NewbDevBoxButtonFrameReloadButton, NewbDevBoxButtonFrameReloadButton
    local lastCount = 1
    local buttonFrameHeight = NumberList.buttonFrameDefaultHeight
    NewbDevBoxButtonFrameLogoutButton:Hide() -- hide all buttons to ensure no ghosting
    NewbDevBoxButtonFrameExitButton:Hide()
    NewbDevBoxButtonFrameFStackButton:Hide()
    NewbDevBoxButtonFrameClearChatButton:Hide()
    NewbDevBoxButtonFrameChatSpacerButton:Hide()
    NewbDevBoxButtonFrameETraceButton:Hide()
    NewbDevBoxButtonFrameETraceStartButton:Hide()
    NewbDevBoxButtonFrameETraceStopButton:Hide()
    NewbDevBoxButtonFrameChatLogButton:Hide()
    NewbDevBoxButtonFrameCombatLogButton:Hide()
    NewbDevBoxButtonFrameVersionButton:Hide()
    NewbDevBoxButtonFrameBugSackButton:Hide()
    NewbDevBoxButtonFrameBugSackClearButton:Hide()
    NewbDevBoxButtonFrameWoWLuaButton:Hide()
    NewbDevBoxButtonFrameREHackButton:Hide()
    NewbDevBoxButtonFrameViragDevToolButton:Hide()
    NewbDevBoxButtonFrameAPIInterfaceButton:Hide()
    NewbDevBoxButtonFrameHandleItButton:Hide()
    NewbDevBoxButtonFrameWhatsOnTheMapButton:Hide()
    NewbDevBoxButtonFrameCubeCodeButton:Hide()
    NewbDevBoxButtonFrameCubeBrowserButton:Hide()
    NewbDevBoxButtonFrameAddonUsageButton:Hide()
    NewbDevBoxButtonFrame:SetSize(NumberList.buttonFrameWidth, buttonFrameHeight) -- reset frame size
    for index = 1, #SortedNewbDevBoxButtonTable do -- loop through the sorting table
        tableIndex = SortedNewbDevBoxButtonTable[index] -- get the current index
        tableAtIndex = NewbDevBoxDisplayButtonsList[tableIndex] -- get the table held in the button table index
        for k, v in pairs(tableAtIndex) do -- loop through the table at index
            if v then
                thisButton = _G["NewbDevBoxButtonFrame" .. k] -- set this button to the global button name
                thisButton:ClearAllPoints()
                thisButton:Show()
                if mod(lastCount, 3) == 0 then -- when the button count reaches 3
                    thisButton:SetPoint("TOP", lastOnTop, "BOTTOM", 0, -5) -- set the button point to the last top button
                    lastOnTop = thisButton -- set the current button as the lastOnTop button
                    buttonFrameHeight = buttonFrameHeight + NumberList.buttonFrameHeightExpander -- expand the frame to allow another row of buttons
                    NewbDevBoxButtonFrame:SetSize(NumberList.buttonFrameWidth, buttonFrameHeight) -- set the frame size
                else
                    thisButton:SetPoint("LEFT", lastRelative, "RIGHT", NumberList.actionButtonSideGap, 0) -- set the button point to the last button
                end
                lastCount = lastCount + 1 -- increase the lastCount
                lastRelative = thisButton -- set this button to the lastRelative
            end
        end
    end
end

local function updateButtonFrameScale(updateScaleNumber)
    if updateScaleNumber >= 301 then -- if the entered number is too high
        updateScaleNumber = 300
    elseif updateScaleNumber <= 49 then -- if the entered number is too low
        updateScaleNumber = 50
    end
    NewbDevBoxOptionsTable.ButtonFrameScale = updateScaleNumber / 100
    NewbDevBoxButtonFrame:SetScale(NewbDevBoxOptionsTable.ButtonFrameScale)
    NewbDevBoxInterfaceFrame.ScaleTextBox:SetNumber(updateScaleNumber)
end

local function updateButtonFrameOpacity(updateOpacityNumber)
    if updateOpacityNumber >= 101 then -- if the entered number is too high
        updateOpacityNumber = 100
    elseif updateOpacityNumber <= 24 then -- if the entered number is too low
        updateOpacityNumber = 25
    end
    NewbDevBoxOptionsTable.ButtonFrameOpacity = updateOpacityNumber / 100
    NewbDevBoxButtonFrame:SetAlpha(NewbDevBoxOptionsTable.ButtonFrameOpacity)
    NewbDevBoxInterfaceFrame.OpacityTextBox:SetNumber(updateOpacityNumber)
end

-- ===================================================================================================
-- ===================================================================================================
-- ===========================         global functions for keybinds       ===========================
-- ===================================================================================================
-- ===================================================================================================

-- ===========================         toggle newb dev box interface frame          ===========================
function NEWBDEVBOXTOGGLENEWBDEVBOXINTERFACEFRAME()
    if SettingsPanel:IsShown() then
        HideUIPanel(SettingsPanel)
    else
        --        HideUIPanel(SettingsPanel)
        --         InterfaceOptionsFrame_OpenToCategory(NewbDevBoxInterfaceFrame) -- have to do this twice because reasons
        InterfaceOptionsFrame_OpenToCategory(NewbDevBoxInterfaceFrame) -- debug --
    end
end

-- ===========================         toggle new dev box button frame          ===========================
function NEWBDEVBOXTOGGLENEWBDEVBOXBUTTONFRAME()
    if NewbDevBoxButtonFrame:IsShown() then
        NewbDevBoxButtonFrame:Hide()
    else
        NewbDevBoxButtonFrame:Show()
    end
end

-- ===================================================================================================
-- ===================================================================================================
-- ===========================         slash commands          ===========================
-- ===================================================================================================
-- ===================================================================================================

-- ===========================         toggle newb dev box interface frame          ===========================
SLASH_NEWBDEVBOXI1 = "/NDBI"
function SlashCmdList.NEWBDEVBOXI(msg, editbox)
    NEWBDEVBOXTOGGLENEWBDEVBOXINTERFACEFRAME()
end

-- ===========================         toggle new dev box button frame          ===========================
SLASH_NEWBDEVBOXF1 = "/NDBF"
function SlashCmdList.NEWBDEVBOXF(msg, editbox)
    NEWBDEVBOXTOGGLENEWBDEVBOXBUTTONFRAME()
end

-- ===================================================================================================
-- ===================================================================================================
-- ===========================                 Frames                      ===========================
-- ===================================================================================================
-- ===================================================================================================

local NewbDevBoxInterfaceFrame = CreateFrame("Frame", "NewbDevBoxInterfaceFrame", UIParent, "BackdropTemplate")
NewbDevBoxInterfaceFrame.name = "Newb Dev Box"
NewbDevBoxInterfaceFrame:SetBackdrop(
    {
        bgFile = "Interface\\Buttons\\WHITE8X8",
        insets = {
            left = NumberList.insetSize,
            right = NumberList.insetSize,
            top = NumberList.insetSize,
            bottom = NumberList.insetSize
        },
        tileSize = nil,
        tile = false,
        edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
        edgeSize = NumberList.edgeSize
    }
)
NewbDevBoxInterfaceFrame:SetBackdropColor(unpack(TextDimensionList.colourBackdrop))
NewbDevBoxInterfaceFrame:SetBackdropBorderColor(unpack(TextDimensionList.colourBorder))
NewbDevBoxInterfaceFrame:SetScript(
    "OnEvent",
    function(self, event, ...)
        if event == "PLAYER_LOGIN" then -- fires when a player logs in or reloads
            print(TextStringList.addonLoaded) -- Load Message
            initialiseLists()
            setUpNewbDevBoxSortedTable()
            checkOtherAddonsEnabled()
            setCheckBoxesAndButtonFrameMetrics()
            buttonFrameButtonLayout()
        end
    end
)
NewbDevBoxInterfaceFrame:RegisterEvent("PLAYER_LOGIN") -- fires when a player logs in or reloads
NewbDevBoxInterfaceFrame:RegisterEvent("ADDON_LOADED") -- fires when an addon is loaded
InterfaceOptions_AddCategory(NewbDevBoxInterfaceFrame)

NewbDevBoxInterfaceFrame.TitleBox = CreateFrame("Frame", "NewbDevBoxInterfaceFrameTitleBox", NewbDevBoxInterfaceFrame)
NewbDevBoxInterfaceFrame.TitleBox:SetSize(NumberList.titleFrameWidth, NumberList.titleFrameHeight)
NewbDevBoxInterfaceFrame.TitleBox:SetPoint("TOP", NewbDevBoxInterfaceFrame, 0, NumberList.titleFrameGap)
NewbDevBoxInterfaceFrame.TitleBox.Text =
    NewbDevBoxInterfaceFrame.TitleBox:CreateFontString("NewbDevBoxInterfaceFrameTitleBoxText")
NewbDevBoxInterfaceFrame.TitleBox.Text:SetAllPoints(NewbDevBoxInterfaceFrameTitleBox)
NewbDevBoxInterfaceFrame.TitleBox.Text:SetFontObject(NewbDevBoxTitle)
NewbDevBoxInterfaceFrame.TitleBox.Text:SetText(TextStringList.interfaceTitle)

NewbDevBoxInterfaceFrame.KeybindsButton =
    CreateFrame(
    "Button",
    "NewbDevBoxInterfaceFrameKeybindsButton",
    NewbDevBoxInterfaceFrame,
    "BackdropTemplate",
    "UIMenuButtonStretchTemplate"
)
NewbDevBoxInterfaceFrame.KeybindsButton:SetSize(NumberList.keybindingsButtonWidth, NumberList.keybindingsButtonHeight)
NewbDevBoxInterfaceFrame.KeybindsButton:SetPoint(
    "TOPLEFT",
    NewbDevBoxInterfaceFrame,
    "TOPLEFT",
    NumberList.scaleTextBoxXGap,
    NumberList.checkBoxMainTopGap
)
NewbDevBoxInterfaceFrame.KeybindsButton:SetBackdrop(
    {
        bgFile = nil,
        insets = nil,
        tileSize = nil,
        tile = nil,
        edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
        edgeSize = NumberList.edgeSize
    }
)
NewbDevBoxInterfaceFrame.KeybindsButton:SetBackdropBorderColor(unpack(TextDimensionList.colourBorder))
NewbDevBoxInterfaceFrame.KeybindsButton:SetNormalFontObject(TextDimensionList.keybindButtonFont)
NewbDevBoxInterfaceFrame.KeybindsButton:SetHighlightFontObject(TextDimensionList.keybindButtonFont)
NewbDevBoxInterfaceFrame.KeybindsButton:SetText(TextStringList.keyBinding)
NewbDevBoxInterfaceFrame.KeybindsButton:SetScript(
    "OnClick",
    function()
        NewbDevBoxInterfaceFrame:Hide()
        GameMenuButtonSettings:Click("RightButton")
        SettingsPanel.GameTab:Click("RightButton")
--        SettingsPanel.Container.SettingsList:Show()
        for _, v in pairs(KeyBindingFrame.categoryList.buttons) do
            if v:GetText() == "Walkerbo's Addons" or v:GetText() == "WALKERBO'S ADDONS" then
                v:Click()
            end
        end
    end
)

NewbDevBoxInterfaceFrame.ToggleFrameButton =
    CreateFrame(
    "Button",
    "NewbDevBoxInterfaceFrameToggleFrameButton",
    NewbDevBoxInterfaceFrame,
    "BackdropTemplate",
    "UIMenuButtonStretchTemplate"
)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetSize(
    NumberList.keybindingsButtonWidth,
    NumberList.keybindingsButtonHeight
)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetPoint(
    "TOPLEFT",
    NewbDevBoxInterfaceFrameKeybindsButton,
    "BOTTOMLEFT",
    0,
    NumberList.textBoxYGap
)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetBackdrop(
    {
        bgFile = nil,
        insets = nil,
        tileSize = nil,
        tile = nil,
        edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
        edgeSize = NumberList.edgeSize
    }
)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetBackdropBorderColor(unpack(TextDimensionList.colourBorder))
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetNormalFontObject(TextDimensionList.keybindButtonFont)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetHighlightFontObject(TextDimensionList.keybindButtonFont)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetText(TextStringList.toggleFrame)
NewbDevBoxInterfaceFrame.ToggleFrameButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxButtonFrame:IsShown() then
            NewbDevBoxButtonFrame:Hide()
        else
            NewbDevBoxButtonFrame:Show()
        end
    end
)

NewbDevBoxInterfaceFrame.ScaleTextBox =
    CreateFrame("EditBox", "NewbDevBoxInterfaceFrameScaleTextBox", NewbDevBoxInterfaceFrame, "UICheckButtonTemplate")
NewbDevBoxInterfaceFrame.ScaleTextBox:SetPoint(
    "TOPLEFT",
    NewbDevBoxInterfaceFrameToggleFrameButton,
    "BOTTOMLEFT",
    0,
    NumberList.textBoxYGap
)
NewbDevBoxInterfaceFrame.ScaleTextBox:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFrame.ScaleTextBox:SetNumeric(true)
NewbDevBoxInterfaceFrame.ScaleTextBox:SetSize(NumberList.scaleTextBoxWidth, NumberList.scaleTextBoxHeight)
NewbDevBoxInterfaceFrame.ScaleTextBox:SetMaxLetters(3)
NewbDevBoxInterfaceFrame.ScaleTextBox:SetAutoFocus()
NewbDevBoxInterfaceFrame.ScaleTextBox:SetJustifyH("CENTER")
NewbDevBoxInterfaceFrame.ScaleTextBox:SetScript(
    "OnEnterPressed",
    function(self)
        scaleNumber = tonumber(NewbDevBoxInterfaceFrame.ScaleTextBox:GetText())
        self:ClearFocus()
        updateButtonFrameScale(scaleNumber)
    end
)
NewbDevBoxInterfaceFrame.ScaleTextBox.Text =
    NewbDevBoxInterfaceFrame:CreateFontString("NewbDevBoxInterfaceFrameScaleTextBoxText")
NewbDevBoxInterfaceFrame.ScaleTextBox.Text:SetPoint("LEFT", NewbDevBoxInterfaceFrameScaleTextBox, "RIGHT")
NewbDevBoxInterfaceFrame.ScaleTextBox.Text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFrame.ScaleTextBox.Text:SetText(TextStringList.textBoxScale)

NewbDevBoxInterfaceFrame.OpacityTextBox =
    CreateFrame("EditBox", "NewbDevBoxInterfaceFrameOpacityTextBox", NewbDevBoxInterfaceFrame, "UICheckButtonTemplate")
NewbDevBoxInterfaceFrame.OpacityTextBox:SetPoint(
    "TOP",
    NewbDevBoxInterfaceFrameScaleTextBox,
    "BOTTOM",
    0,
    NumberList.textBoxYGap
)
NewbDevBoxInterfaceFrame.OpacityTextBox:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFrame.OpacityTextBox:SetNumeric(true)
NewbDevBoxInterfaceFrame.OpacityTextBox:SetSize(NumberList.scaleTextBoxWidth, NumberList.scaleTextBoxHeight)
NewbDevBoxInterfaceFrame.OpacityTextBox:SetMaxLetters(3)
NewbDevBoxInterfaceFrame.OpacityTextBox:SetAutoFocus()
NewbDevBoxInterfaceFrame.OpacityTextBox:SetJustifyH("CENTER")
NewbDevBoxInterfaceFrame.OpacityTextBox:SetScript(
    "OnEnterPressed",
    function(self)
        opacityNumber = tonumber(NewbDevBoxInterfaceFrame.OpacityTextBox:GetText())
        self:ClearFocus()
        updateButtonFrameOpacity(opacityNumber)
    end
)
NewbDevBoxInterfaceFrame.OpacityTextBox.Text =
    NewbDevBoxInterfaceFrame:CreateFontString("NewbDevBoxInterfaceFrameOpacityTextBoxText")
NewbDevBoxInterfaceFrame.OpacityTextBox.Text:SetPoint("LEFT", NewbDevBoxInterfaceFrameOpacityTextBox, "RIGHT")
NewbDevBoxInterfaceFrame.OpacityTextBox.Text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFrame.OpacityTextBox.Text:SetText(TextStringList.textBoxOpacity)

-- ===========================         newb dev box checkboxes          ===========================
local NewbDevBoxInterfaceFramecbLogoutButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbLogoutButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbLogoutButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbLogoutButton:SetPoint(
    "TOPLEFT",
    NewbDevBoxInterfaceFrame,
    "TOPLEFT",
    NumberList.checkBoxMainSideGap,
    NumberList.checkBoxMainTopGap
)
NewbDevBoxInterfaceFramecbLogoutButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbLogoutButton.text:SetText(TextStringList.cbLogout)
NewbDevBoxInterfaceFramecbLogoutButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[1].LogoutButton then
            NewbDevBoxDisplayButtonsList[1].LogoutButton = false
        else
            NewbDevBoxDisplayButtonsList[1].LogoutButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbExitButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbExitButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbExitButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbExitButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbLogoutButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbExitButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbExitButton.text:SetText(TextStringList.cbExit)
NewbDevBoxInterfaceFramecbExitButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[2].ExitButton then
            NewbDevBoxDisplayButtonsList[2].ExitButton = false
        else
            NewbDevBoxDisplayButtonsList[2].ExitButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbFStackButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbFStackButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbFStackButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbFStackButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbExitButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbFStackButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbFStackButton.text:SetText(TextStringList.cbFStack)
NewbDevBoxInterfaceFramecbFStackButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[3].FStackButton then
            NewbDevBoxDisplayButtonsList[3].FStackButton = false
        else
            NewbDevBoxDisplayButtonsList[3].FStackButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbClearChatButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbClearChatButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbClearChatButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbClearChatButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbFStackButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbClearChatButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbClearChatButton.text:SetText(TextStringList.cbClearChat)
NewbDevBoxInterfaceFramecbClearChatButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[4].ClearChatButton then
            NewbDevBoxDisplayButtonsList[4].ClearChatButton = false
        else
            NewbDevBoxDisplayButtonsList[4].ClearChatButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbChatSpacerButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbChatSpacerButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbChatSpacerButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbChatSpacerButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbClearChatButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbChatSpacerButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbChatSpacerButton.text:SetText(TextStringList.cbChatSpacer)
NewbDevBoxInterfaceFramecbChatSpacerButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[5].ChatSpacerButton then
            NewbDevBoxDisplayButtonsList[5].ChatSpacerButton = false
        else
            NewbDevBoxDisplayButtonsList[5].ChatSpacerButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbETraceButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbETraceButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbETraceButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbETraceButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbChatSpacerButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbETraceButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbETraceButton.text:SetText(TextStringList.cbETrace)
NewbDevBoxInterfaceFramecbETraceButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[6].ETraceButton then
            NewbDevBoxDisplayButtonsList[6].ETraceButton = false
        else
            NewbDevBoxDisplayButtonsList[6].ETraceButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbETraceStartButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbETraceStartButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbETraceStartButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbETraceStartButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbETraceButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbETraceStartButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbETraceStartButton.text:SetText(TextStringList.cbEtraceStart)
NewbDevBoxInterfaceFramecbETraceStartButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[7].ETraceStartButton then
            NewbDevBoxDisplayButtonsList[7].ETraceStartButton = false
        else
            NewbDevBoxDisplayButtonsList[7].ETraceStartButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbETraceStopButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbETraceStopButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbETraceStopButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbETraceStopButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbETraceStartButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbETraceStopButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbETraceStopButton.text:SetText(TextStringList.cbEtraceStop)
NewbDevBoxInterfaceFramecbETraceStopButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[8].ETraceStopButton then
            NewbDevBoxDisplayButtonsList[8].ETraceStopButton = false
        else
            NewbDevBoxDisplayButtonsList[8].ETraceStopButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbChatLogButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbChatLogButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbChatLogButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbChatLogButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbETraceStopButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbChatLogButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbChatLogButton.text:SetText(TextStringList.cbChatLog)
NewbDevBoxInterfaceFramecbChatLogButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[9].ChatLogButton then
            NewbDevBoxDisplayButtonsList[9].ChatLogButton = false
        else
            NewbDevBoxDisplayButtonsList[9].ChatLogButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbCombatLogButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbCombatLogButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbCombatLogButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbCombatLogButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbChatLogButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbCombatLogButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbCombatLogButton.text:SetText(TextStringList.cbCombatLog)
NewbDevBoxInterfaceFramecbCombatLogButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[10].CombatLogButton then
            NewbDevBoxDisplayButtonsList[10].CombatLogButton = false
        else
            NewbDevBoxDisplayButtonsList[10].CombatLogButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbVersionButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbVersionButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbVersionButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbVersionButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbCombatLogButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbVersionButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbVersionButton.text:SetText(TextStringList.cbVersionButton)
NewbDevBoxInterfaceFramecbVersionButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[11].VersionButton then
            NewbDevBoxDisplayButtonsList[11].VersionButton = false
        else
            NewbDevBoxDisplayButtonsList[11].VersionButton = true
        end
        buttonFrameButtonLayout()
    end
)

-- ===========================         other addon checkboxes          ===========================
local NewbDevBoxInterfaceFramecbBugSackButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbBugSackButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbBugSackButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbBugSackButton:SetPoint(
    "LEFT",
    NewbDevBoxInterfaceFramecbLogoutButton,
    "RIGHT",
    NumberList.checkBoxElementXGap,
    0
)
NewbDevBoxInterfaceFramecbBugSackButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbBugSackButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbBugSackButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbBugSackButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbBugSackButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[12].BugSackButton then
            NewbDevBoxDisplayButtonsList[12].BugSackButton = false
        else
            NewbDevBoxDisplayButtonsList[12].BugSackButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbBugSackClearButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbBugSackClearButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbBugSackClearButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbBugSackClearButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbBugSackButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbBugSackClearButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbBugSackClearButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbBugSackClearButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbBugSackClearButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbBugSackClearButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[13].BugSackClearButton then
            NewbDevBoxDisplayButtonsList[13].BugSackClearButton = false
        else
            NewbDevBoxDisplayButtonsList[13].BugSackClearButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbWoWLuaButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbWoWLuaButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbWoWLuaButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbWoWLuaButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbBugSackClearButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbWoWLuaButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbWoWLuaButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbWoWLuaButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbWoWLuaButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbWoWLuaButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[14].WoWLuaButton then
            NewbDevBoxDisplayButtonsList[14].WoWLuaButton = false
        else
            NewbDevBoxDisplayButtonsList[14].WoWLuaButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbREHackButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbREHackButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbREHackButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbREHackButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbWoWLuaButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbREHackButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbREHackButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbREHackButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbREHackButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbREHackButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[15].REHackButton then
            NewbDevBoxDisplayButtonsList[15].REHackButton = false
        else
            NewbDevBoxDisplayButtonsList[15].REHackButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbViragDevToolButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbViragDevToolButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbViragDevToolButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbViragDevToolButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbREHackButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbViragDevToolButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbViragDevToolButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbViragDevToolButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbViragDevToolButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbViragDevToolButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[16].ViragDevToolButton then
            NewbDevBoxDisplayButtonsList[16].ViragDevToolButton = false
        else
            NewbDevBoxDisplayButtonsList[16].ViragDevToolButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbAPIInterfaceButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbAPIInterfaceButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbAPIInterfaceButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbAPIInterfaceButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbViragDevToolButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbAPIInterfaceButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbAPIInterfaceButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbAPIInterfaceButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbAPIInterfaceButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbAPIInterfaceButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[17].APIInterfaceButton then
            NewbDevBoxDisplayButtonsList[17].APIInterfaceButton = false
        else
            NewbDevBoxDisplayButtonsList[17].APIInterfaceButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbHandleItButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbHandleItButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbHandleItButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbHandleItButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbAPIInterfaceButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbHandleItButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbHandleItButton.text:SetText(TextDimensionList.disabledTextColour .. TextStringList.cbHandleIt) -- default grey checkbox text
NewbDevBoxInterfaceFramecbHandleItButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbHandleItButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[18].HandleItButton then
            NewbDevBoxDisplayButtonsList[18].HandleItButton = false
        else
            NewbDevBoxDisplayButtonsList[18].HandleItButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbWhatsOnTheMapButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbWhatsOnTheMapButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbHandleItButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbWhatsOnTheMapButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbWhatsOnTheMapButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[19].WhatsOnTheMapButton then
            NewbDevBoxDisplayButtonsList[19].WhatsOnTheMapButton = false
        else
            NewbDevBoxDisplayButtonsList[19].WhatsOnTheMapButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbCubeCodeButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbCubeCodeButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbCubeCodeButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbCubeCodeButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbWhatsOnTheMapButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbCubeCodeButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbCubeCodeButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbCubeCodeButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbCubeCodeButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbCubeCodeButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[20].CubeCodeButton then
            NewbDevBoxDisplayButtonsList[20].CubeCodeButton = false
        else
            NewbDevBoxDisplayButtonsList[20].CubeCodeButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbCubeBrowserButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbCubeBrowserButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbCubeBrowserButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbCubeBrowserButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbCubeCodeButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbCubeBrowserButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbCubeBrowserButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbCubeBrowserButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbCubeBrowserButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbCubeBrowserButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[21].CubeBrowserButton then
            NewbDevBoxDisplayButtonsList[21].CubeBrowserButton = false
        else
            NewbDevBoxDisplayButtonsList[21].CubeBrowserButton = true
        end
        buttonFrameButtonLayout()
    end
)

local NewbDevBoxInterfaceFramecbAddonUsageButton =
    CreateFrame(
    "CheckButton",
    "NewbDevBoxInterfaceFramecbAddonUsageButton",
    NewbDevBoxInterfaceFrame,
    "UICheckButtonTemplate"
)
NewbDevBoxInterfaceFramecbAddonUsageButton:SetSize(NumberList.checkBoxSize, NumberList.checkBoxSize)
NewbDevBoxInterfaceFramecbAddonUsageButton:SetPoint(
    "BOTTOMLEFT",
    NewbDevBoxInterfaceFramecbCubeBrowserButton,
    "TOPLEFT",
    0,
    NumberList.checkBoxElementYGap
)
NewbDevBoxInterfaceFramecbAddonUsageButton.text:SetFontObject(TextDimensionList.checkBoxFont)
NewbDevBoxInterfaceFramecbAddonUsageButton.text:SetText(
    TextDimensionList.disabledTextColour .. TextStringList.cbAddonUsageButton
) -- default grey checkbox text
NewbDevBoxInterfaceFramecbAddonUsageButton:Disable() -- default disable checkbox
NewbDevBoxInterfaceFramecbAddonUsageButton:SetScript(
    "OnClick",
    function()
        if NewbDevBoxDisplayButtonsList[22].AddonUsageButton then
            NewbDevBoxDisplayButtonsList[22].AddonUsageButton = false
        else
            NewbDevBoxDisplayButtonsList[22].AddonUsageButton = true
        end
        buttonFrameButtonLayout()
    end
)

-- ===================================================================================================
-- ===================================================================================================
-- ===========================         button frame          ===========================
-- ===================================================================================================
-- ===================================================================================================

local NewbDevBoxButtonFrame = CreateFrame("Frame", "NewbDevBoxButtonFrame", UIParent, "UIPanelDialogTemplate")
NewbDevBoxButtonFrame:SetSize(NumberList.buttonFrameWidth, NumberList.buttonFrameDefaultHeight)
NewbDevBoxButtonFrame:ClearAllPoints()
NewbDevBoxButtonFrame:SetPoint("CENTER")
NewbDevBoxButtonFrame:EnableMouse(true)
NewbDevBoxButtonFrame:SetMovable(true)
NewbDevBoxButtonFrame:SetClampedToScreen(true)
NewbDevBoxButtonFrame:RegisterForDrag("RightButton", "LeftButton")
NewbDevBoxButtonFrame:SetScript("OnDragStart", NewbDevBoxButtonFrame.StartMoving)
NewbDevBoxButtonFrame:SetScript("OnDragStop", NewbDevBoxButtonFrame.StopMovingOrSizing)
NewbDevBoxButtonFrame:SetToplevel(true)
NewbDevBoxButtonFrame:SetScript(
    "OnEnter",
    function()
        NewbDevBoxButtonFrame:SetAlpha(1)
    end
)
NewbDevBoxButtonFrame:SetScript(
    "OnLeave",
    function()
        NewbDevBoxButtonFrame:SetAlpha(NewbDevBoxOptionsTable.ButtonFrameOpacity)
    end
)

NewbDevBoxButtonFrame.TitleButton = CreateFrame("Button", "NewbDevBoxButtonFrameTitleButton", NewbDevBoxButtonFrame)
NewbDevBoxButtonFrame.TitleButton:SetSize(NumberList.buttonFrameTitleButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrame.TitleButton:SetPoint("TOP", NewbDevBoxButtonFrame, "TOP", 0, -1)
NewbDevBoxButtonFrame.TitleButton:SetText(TextDimensionList.addonColour .. TextStringList.btnNewbDevBox)
NewbDevBoxButtonFrame.TitleButton:SetNormalFontObject(NewbDevBoxButton)
NewbDevBoxButtonFrame.TitleButton:SetHighlightFontObject(NewbDevBoxButton)
NewbDevBoxButtonFrame.TitleButton:SetScript(
    "OnClick",
    function()
        NEWBDEVBOXTOGGLENEWBDEVBOXINTERFACEFRAME()
    end
)

NewbDevBoxButtonFrame.ReloadButton =
    CreateFrame("Button", "NewbDevBoxButtonFrameReloadButton", NewbDevBoxButtonFrame, TextDimensionList.buttonTemplate)
NewbDevBoxButtonFrame.ReloadButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrame.ReloadButton:SetPoint(
    "TOPLEFT",
    NewbDevBoxButtonFrame,
    "TOPLEFT",
    NumberList.actionButtonSideFrameGap,
    NumberList.actionButtonTopGap
)

NewbDevBoxButtonFrame.ReloadButton:SetText(TextStringList.btnReload)
NewbDevBoxButtonFrame.ReloadButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrame.ReloadButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrame.ReloadButton:SetScript(
    "OnClick",
    function()
        ReloadUI()
    end
)

local NewbDevBoxButtonFrameLogoutButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameLogoutButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameLogoutButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameLogoutButton:SetText(TextStringList.btnLogout)
NewbDevBoxButtonFrameLogoutButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameLogoutButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameLogoutButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameLogoutButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameLogoutButton:SetAttribute("macrotext", "/logout")

local NewbDevBoxButtonFrameExitButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameExitButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameExitButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameExitButton:SetText(TextStringList.btnExit)
NewbDevBoxButtonFrameExitButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameExitButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameExitButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameExitButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameExitButton:SetAttribute("macrotext", "/exit")

local NewbDevBoxButtonFrameFStackButton =
    CreateFrame("Button", "NewbDevBoxButtonFrameFStackButton", NewbDevBoxButtonFrame, TextDimensionList.buttonTemplate)
NewbDevBoxButtonFrameFStackButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameFStackButton:SetText(TextStringList.btnFStack)
NewbDevBoxButtonFrameFStackButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameFStackButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameFStackButton:SetScript(
    "OnClick",
    function(self)
        if not FrameStackTooltip_Toggle then
            LoadAddOn("Blizzard_DebugTools")
        end
        FrameStackTooltip_Toggle()
    end
)

local NewbDevBoxButtonFrameClearChatButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameClearChatButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameClearChatButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameClearChatButton:SetText(TextStringList.btnClearChat)
NewbDevBoxButtonFrameClearChatButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameClearChatButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameClearChatButton:SetScript(
    "OnClick",
    function()
        SELECTED_CHAT_FRAME:Clear()
    end
)

local NewbDevBoxButtonFrameChatSpacerButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameChatSpacerButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameChatSpacerButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameChatSpacerButton:SetText(TextStringList.btnChatSpacer)
NewbDevBoxButtonFrameChatSpacerButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameChatSpacerButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameChatSpacerButton:SetScript(
    "OnClick",
    function()
        print(TextStringList.printChatSpacer)
        print(TextStringList.printChatSpacer)
    end
)

local NewbDevBoxButtonFrameETraceButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameETraceButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameETraceButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameETraceButton:SetText(TextStringList.btnETrace)
NewbDevBoxButtonFrameETraceButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameETraceButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameETraceButton:SetAttribute("macrotext", "/eventtrace")

local NewbDevBoxButtonFrameETraceStartButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameETraceStartButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameETraceStartButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameETraceStartButton:SetText(TextStringList.btnEtraceStart)
NewbDevBoxButtonFrameETraceStartButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceStartButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceStartButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameETraceStartButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameETraceStartButton:SetAttribute("macrotext", "/eventtrace start")

local NewbDevBoxButtonFrameETraceStopButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameETraceStopButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameETraceStopButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameETraceStopButton:SetText(TextStringList.btnEtraceStop)
NewbDevBoxButtonFrameETraceStopButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceStopButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameETraceStopButton:SetScript(
    "OnClick",
    function()
        if not FrameStackTooltip_Toggle then
            LoadAddOn("Blizzard_DebugTools")
        end
        EventTraceFrame_StopEventCapture()
    end
)

local NewbDevBoxButtonFrameChatLogButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameChatLogButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameChatLogButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameChatLogButton:SetText(TextStringList.btnChatLog)
NewbDevBoxButtonFrameChatLogButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameChatLogButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameChatLogButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameChatLogButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameChatLogButton:SetAttribute("macrotext", "/chatlog")

local NewbDevBoxButtonFrameCombatLogButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameCombatLogButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameCombatLogButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameCombatLogButton:SetText(TextStringList.btnCombatLog)
NewbDevBoxButtonFrameCombatLogButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCombatLogButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCombatLogButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameCombatLogButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameCombatLogButton:SetAttribute("macrotext", "/combatlog")

local NewbDevBoxButtonFrameVersionButton =
    CreateFrame("Button", "NewbDevBoxButtonFrameVersionButton", NewbDevBoxButtonFrame, TextDimensionList.buttonTemplate)
NewbDevBoxButtonFrameVersionButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameVersionButton:SetText(TextStringList.btnVersionButton)
NewbDevBoxButtonFrameVersionButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameVersionButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameVersionButton:SetScript(
    "OnClick",
    function()
        print(TextStringList.printChatSpacer)
        print(TextStringList.printVersion, select(4, GetBuildInfo()))
        print(TextStringList.printChatSpacer)
    end
)

-- ===========================         other addon buttons          ===========================
local NewbDevBoxButtonFrameBugSackButton =
    CreateFrame("Button", "NewbDevBoxButtonFrameBugSackButton", NewbDevBoxButtonFrame, TextDimensionList.buttonTemplate)
NewbDevBoxButtonFrameBugSackButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameBugSackButton:SetText(TextStringList.btnBugSackButton)
NewbDevBoxButtonFrameBugSackButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameBugSackButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameBugSackButton:SetScript(
    "OnClick",
    function()
        if BugSackFrame and BugSackFrame:IsShown() then
            bugsackFunctions:CloseSack()
        else
            bugsackFunctions:OpenSack()
        end
    end
)

local NewbDevBoxButtonFrameBugSackClearButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameBugSackClearButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameBugSackClearButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameBugSackClearButton:SetText(TextStringList.btnBugSackClearButton)
NewbDevBoxButtonFrameBugSackClearButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameBugSackClearButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameBugSackClearButton:SetScript(
    "OnClick",
    function()
        bugsackFunctions:Reset()
    end
)

local NewbDevBoxButtonFrameWoWLuaButton =
    CreateFrame("Button", "NewbDevBoxButtonFrameWoWLuaButton", NewbDevBoxButtonFrame, TextDimensionList.buttonTemplate)
NewbDevBoxButtonFrameWoWLuaButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameWoWLuaButton:SetText(TextStringList.btnWoWLuaButton)
NewbDevBoxButtonFrameWoWLuaButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameWoWLuaButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameWoWLuaButton:SetScript(
    "OnClick",
    function()
        if WowLuaFrame:IsShown() then
            WowLuaFrame:Hide()
        else
            WowLuaFrame:Show()
        end
    end
)

local NewbDevBoxButtonFrameREHackButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameREHackButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameREHackButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameREHackButton:SetText(TextStringList.btnREHackButton)
NewbDevBoxButtonFrameREHackButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameREHackButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameREHackButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameREHackButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameREHackButton:SetAttribute("macrotext", "/hack")

local NewbDevBoxButtonFrameViragDevToolButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameViragDevToolButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameViragDevToolButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameViragDevToolButton:SetText(TextStringList.btnViragDevToolButton)
NewbDevBoxButtonFrameViragDevToolButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameViragDevToolButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameViragDevToolButton:SetScript(
    "OnClick",
    function()
        ViragDevTool:ToggleUI()
    end
)

local NewbDevBoxButtonFrameAPIInterfaceButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameAPIInterfaceButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameAPIInterfaceButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameAPIInterfaceButton:SetText(TextStringList.btnAPIInterfaceButton)
NewbDevBoxButtonFrameAPIInterfaceButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameAPIInterfaceButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameAPIInterfaceButton:SetScript(
    "OnClick",
    function()
        if APII_Core:IsShown() then
            APII_Core:Hide()
        else
            APII_Core:Show()
        end
    end
)

local NewbDevBoxButtonFrameHandleItButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameHandleItButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameHandleItButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameHandleItButton:SetText(TextStringList.btnHandleIt)
NewbDevBoxButtonFrameHandleItButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameHandleItButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameHandleItButton:SetScript(
    "OnClick",
    function()
        if InterfaceOptionsFrame:IsShown() then
            InterfaceOptionsFrame:Hide()
        else
            InterfaceOptionsFrame:Show()
            InterfaceOptionsFrameTab2:Click() -- click the addons tab
            for k, v in pairs(INTERFACEOPTIONS_ADDONCATEGORIES) do -- loop through all categories
                for a, b in pairs(v) do -- loop through the current category
                    if b == "HandleIt" then -- if the current name value
                        thisButton = _G["InterfaceOptionsFrameAddOnsButton" .. k] -- set the button name with the key value
                        thisButton:Click()
                    end
                end
            end
        end
    end
)

local NewbDevBoxButtonFrameWhatsOnTheMapButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameWhatsOnTheMapButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.buttonTemplate
)
NewbDevBoxButtonFrameWhatsOnTheMapButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameWhatsOnTheMapButton:SetText(TextStringList.btnWhatsOnTheMapButton)
NewbDevBoxButtonFrameWhatsOnTheMapButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameWhatsOnTheMapButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameWhatsOnTheMapButton:SetScript(
    "OnClick",
    function()
        if WhatsOnTheMapFrame:IsShown() then
            WhatsOnTheMapFrame:Hide()
        else
            WhatsOnTheMapFrame:Show()
        end
    end
)

local NewbDevBoxButtonFrameCubeCodeButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameCubeCodeButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameCubeCodeButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameCubeCodeButton:SetText(TextStringList.btnCubeButton)
NewbDevBoxButtonFrameCubeCodeButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCubeCodeButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCubeCodeButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameCubeCodeButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameCubeCodeButton:SetAttribute("macrotext", "/cube code")

local NewbDevBoxButtonFrameCubeBrowserButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameCubeBrowserButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameCubeBrowserButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameCubeBrowserButton:SetText(TextStringList.btnCubeBrowserButton)
NewbDevBoxButtonFrameCubeBrowserButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCubeBrowserButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameCubeBrowserButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameCubeBrowserButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameCubeBrowserButton:SetAttribute("macrotext", "/cube debug")

local NewbDevBoxButtonFrameAddonUsageButton =
    CreateFrame(
    "Button",
    "NewbDevBoxButtonFrameAddonUsageButton",
    NewbDevBoxButtonFrame,
    TextDimensionList.secureButtonTemplate
)
NewbDevBoxButtonFrameAddonUsageButton:SetSize(NumberList.actionButtonWidth, NumberList.actionButtonHeight)
NewbDevBoxButtonFrameAddonUsageButton:SetText(TextStringList.cbAddonUsageButton)
NewbDevBoxButtonFrameAddonUsageButton:SetNormalFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameAddonUsageButton:SetHighlightFontObject(TextDimensionList.buttonFont)
NewbDevBoxButtonFrameAddonUsageButton:RegisterForClicks("AnyDown")
NewbDevBoxButtonFrameAddonUsageButton:SetAttribute("type", "macro")
NewbDevBoxButtonFrameAddonUsageButton:SetAttribute("macrotext", "/addonusage")
